@@ -780,7 +780,8 @@ class DmApi:
     @synchronized
     def get_job(cls, access_token: str, job_id: int, timeout_s: int = 4)\
             -> DmApiRv:
-        """Gets detailed information about a specific Job.
+        """Gets detailed information about a specific Job
+        using the numeric Job record identity
         """
         assert access_token
         assert job_id > 0
@@ -789,3 +790,53 @@ class DmApi:
                               access_token=access_token,
                               error_message='Failed to get job',
                               timeout=timeout_s)[0]
+
+    @classmethod
+    @synchronized
+    def get_job_by_name(cls,
+                        access_token: str,
+                        job_collection: str,
+                        job_name: str,
+                        job_version: str,
+                        timeout_s: int = 4)\
+            -> DmApiRv:
+        """Gets detailed information about a specific Job
+        using the collection, name and version
+        """
+        assert access_token
+        assert job_collection
+        assert job_name
+        assert job_version
+
+        params: Dict[str, Any] = {'collection': job_collection,
+                                  'name': job_name,
+                                  'version': job_version}
+        return DmApi._request('GET', '/job/get-by-name',
+                              access_token=access_token,
+                              params=params,
+                              error_message='Failed to get job',
+                              timeout=timeout_s)[0]
+
+    @classmethod
+    @synchronized
+    def set_admin_state(cls,
+                        access_token: str,
+                        admin: bool,
+                        impersonate: Optional[str] = None,
+                        timeout_s: int = 4)\
+            -> DmApiRv:
+        """Adds or removes the 'become-admin' state of your account,
+        assuming you can do this.
+        """
+        assert access_token
+
+        data: Dict[str, Any] = {'become_admin': admin}
+        if impersonate:
+            data['impersonate'] = impersonate
+
+        return DmApi._request('PATCH', '/user/account',
+                              access_token=access_token,
+                              data=data,
+                              expected_response_codes=[204],
+                              error_message='Failed to set the admin state',
+                              timeout=timeout_s)[0]
